@@ -1,23 +1,27 @@
 #!/usr/bin/env python3
 """
- SPDX-License-Identifier: GPL-2.0-or-later
+ SPDX-License-Identifier: MIT
 
-   Copyright (C) 2018-2021 SCANOSS LTD
+   Copyright (c) 2021, SCANOSS
 
-   This program is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
-   (at your option) any later version.
+   Permission is hereby granted, free of charge, to any person obtaining a copy
+   of this software and associated documentation files (the "Software"), to deal
+   in the Software without restriction, including without limitation the rights
+   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+   copies of the Software, and to permit persons to whom the Software is
+   furnished to do so, subject to the following conditions:
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   The above copyright notice and this permission notice shall be included in
+   all copies or substantial portions of the Software.
 
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+   THE SOFTWARE.
 """
-
 import argparse
 import os
 import sys
@@ -38,7 +42,7 @@ def setup_args() -> None:
     """
     Setup all the command line arguments for processing
     """
-    parser = argparse.ArgumentParser(description=f'SCANOSS Python CLI. Ver: {__version__}, License: GPL 2.0-or-later')
+    parser = argparse.ArgumentParser(description=f'SCANOSS Python CLI. Ver: {__version__}, License: MIT')
     subparsers = parser.add_subparsers(title='Sub Commands', dest='subparser', description='valid subcommands',
                                        help='sub-command help'
                                        )
@@ -72,6 +76,7 @@ def setup_args() -> None:
     p_scan.add_argument('--post-size', '-P', type=int, default=64,
                         help='Number of kilobytes to limit the post to while scanning'
                         )
+    p_scan.add_argument('--timeout', '-M', type=int, default=120, help='Timeout (in seconds) for API communication')
 
     # Sub-command: fingerprint
     p_wfp = subparsers.add_parser('fingerprint', aliases=['fp', 'wfp'],
@@ -193,13 +198,22 @@ def scan(parser, args):
             print_stderr("Skipping snippets...")
         if args.post_size != 64:
             print_stderr(f'Changing scanning POST size to: {args.post_size}k...')
+        if args.timeout != 120:
+            print_stderr(f'Changing scanning POST timeout to: {args.timeout}...')
+    elif not args.quiet:
+        if args.timeout < 5:
+            print_stderr(f'POST timeout (--timeout) too small: {args.timeout}. Reverting to default.')
 
     scanner = Scanner(debug=args.debug, trace=args.trace, quiet=args.quiet, api_key=args.key, url=args.apiurl,
                       sbom_path=sbom_path, scan_type=scan_type, scan_output=scan_output, output_format=output_format,
-                      flags=flags, nb_threads=args.threads, skip_snippets=args.skip_snippets, post_size=args.post_size
+                      flags=flags, nb_threads=args.threads, skip_snippets=args.skip_snippets, post_size=args.post_size,
+                      timeout=args.timeout
                       )
     if args.wfp:
-        scanner.scan_wfp_file(args.wfp)
+        if args.threads > 1:
+            scanner.scan_wfp_file_threaded(args.wfp)
+        else:
+            scanner.scan_wfp_file(args.wfp)
     elif args.scan_dir:
         if not os.path.exists(args.scan_dir):
             print_stderr(f'Error: File or folder specified does not exist: {args.scan_dir}.')
