@@ -1,20 +1,25 @@
 """
- SPDX-License-Identifier: GPL-2.0-or-later
+ SPDX-License-Identifier: MIT
 
-   Copyright (C) 2018-2021 SCANOSS LTD
+   Copyright (c) 2021, SCANOSS
 
-   This program is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
-   (at your option) any later version.
+   Permission is hereby granted, free of charge, to any person obtaining a copy
+   of this software and associated documentation files (the "Software"), to deal
+   in the Software without restriction, including without limitation the rights
+   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+   copies of the Software, and to permit persons to whom the Software is
+   furnished to do so, subject to the following conditions:
 
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   The above copyright notice and this permission notice shall be included in
+   all copies or substantial portions of the Software.
 
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+   THE SOFTWARE.
 """
 import logging
 import os
@@ -36,7 +41,8 @@ class ScanossApi:
     Currently support posting scan requests to the SCANOSS streaming API
     """
     def __init__(self, scan_type: str = None, sbom_path: str = None, scan_format: str = None, flags: str = None,
-                 url: str = None, api_key: str = None, debug: bool = False, trace: bool = False, quiet: bool = False):
+                 url: str = None, api_key: str = None, debug: bool = False, trace: bool = False, quiet: bool = False,
+                 timeout: int = 120):
         """
         Initialise the SCANOSS API
         :param scan_type: Scan type (default identify)
@@ -58,6 +64,7 @@ class ScanossApi:
         self.sbom_path = sbom_path
         self.scan_format = scan_format if scan_format else 'plain'
         self.flags = flags
+        self.timeout = timeout if timeout > 5 else 120
         self.headers = {}
         if self.api_key:
             self.headers['X-Session'] = self.api_key
@@ -103,7 +110,7 @@ class ScanossApi:
             retry += 1
             try:
                 r = None
-                r = requests.post(self.url, files=scan_files, data=form_data, headers=self.headers, timeout=120)
+                r = requests.post(self.url, files=scan_files, data=form_data, headers=self.headers, timeout=self.timeout)
             except (requests.exceptions.Timeout, requests.exceptions.ConnectionError) as e:
                 if retry > 5:   # Timed out 5 or more times, fail
                     self.print_stderr(f'ERROR: Timeout/Connection Error POSTing data: {scan_files}')
